@@ -1,5 +1,5 @@
 package Cwd;
-$VERSION = $VERSION = '2.17_03';
+$VERSION = $VERSION = '2.18_01';
 
 =head1 NAME
 
@@ -146,7 +146,7 @@ C<fast_abs_path()>.
 
 Originally by the perl5-porters.
 
-Now maintained by Ken Williams <KWILLIAMS@cpan.org>
+Maintained by Ken Williams <KWILLIAMS@cpan.org>
 
 =head1 SEE ALSO
 
@@ -597,11 +597,11 @@ sub _vms_cwd {
 
 sub _vms_abs_path {
     return $ENV{'DEFAULT'} unless @_;
+
+    # may need to turn foo.dir into [.foo]
     my $path = VMS::Filespec::pathify($_[0]);
-    if (! defined $path)
-	{
-	_croak("Invalid path name $_[0]")
-	}
+    $path = $_[0] unless defined $path;
+
     return VMS::Filespec::rmsexpand($path);
 }
 
